# Generated by Django 3.0.5 on 2020-04-02 09:42

from django.db import migrations, models
import django.db.models.deletion

from image_assets import defaults


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('image_assets', '0003_auto_20200402_0915'),
    ]

    operations = []
    if defaults.DELETED_ASSET_MODEL == 'image_assets.DeletedAsset':

        operations.extend([
            migrations.AlterField(
                model_name='deletedasset',
                name='asset_type',
                field=models.ForeignKey(
                    on_delete=django.db.models.deletion.CASCADE,
                    to='image_assets.AssetType',
                    verbose_name='Asset Type'),
            ),
            migrations.AlterField(
                model_name='deletedasset',
                name='content_type',
                field=models.ForeignKey(
                    on_delete=django.db.models.deletion.CASCADE,
                    to='contenttypes.ContentType',
                    verbose_name='Content Type'),
            ),
            migrations.AlterField(
                model_name='deletedasset',
                name='image',
                field=models.ImageField(upload_to='', verbose_name='Image'),
            ),
            migrations.AlterField(
                model_name='deletedasset',
                name='object_id',
                field=models.IntegerField(verbose_name='Object ID'),
            ),
        ])